## Toothpaste (dis)similarities

### Description

A set of 50 consumers rated the perceived (dis)similarity of a set of toothpaste brands. The specific question asked was: "Please rate the following pairs of toothpaste brands on the basis of their similarity (1 = very similar, 7 = very dissimilar)." The dataset is used to illustrate multi-dimensional scaling (MDS).

### Variables

A data frame with 45 observations on 4 variables.

- id1 = Brand name of the first product in the paired comparison
- id2 = Brand name of the second product in the paired comparison
- dissimilarity = Measure of dissimilarity calculated as 8-similarity
- similarity = Average respondent similarity score for two brands on a 7-point scale
